@@ -38,6 +38,22 @@ pub struct StyleContext {
     /// Get default [`LineColor`] when missing.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub line_color: Option<LineColor>,
+
+    /// Get default [`TriangleEdgeWidth`] when missing.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub triangle_edge_width: Option<TriangleEdgeWidth>,
+
+    /// Get default [`TriangleFillColor`] when missing.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub triangle_fill_color: Option<TriangleFillColor>,
+
+    /// Get default [`SquareEdgeWidth`] when missing.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub square_edge_width: Option<SquareEdgeWidth>,
+
+    /// Get default [`SquareFillColor`] when missing.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub square_fill_color: Option<SquareFillColor>,
 }
 
 impl StyleResolver {
@@ -46,6 +62,11 @@ impl StyleResolver {
         PointStyle { point_size: Some(self.point_size()), point_color: Some(self.point_color()) }
     }
 
+    /// Get the [`Point3DStyle`] from theme and state.
+    pub fn point3D_style(&self) -> Point3DStyle {
+        Point3DStyle { point_size: Some(self.point_size()), point_color: Some(self.point_color()) }
+    }
+
     /// Get the [`CircleStyle`] from theme and state.
     pub fn circle_style(&self) -> CircleStyle {
         CircleStyle { circle_width: Some(self.circle_width()), circle_color: Some(self.circle_color()) }
@@ -65,6 +86,24 @@ impl StyleResolver {
         LineStyle { line_width: Some(self.line_width()), line_color: Some(self.line_color()) }
     }
 
+    /// Get the [`TriangleStyle`] from theme and state.
+    pub fn triangle_style(&self) -> TriangleStyle {
+        TriangleStyle {
+            triangle_edge_width: Some(self.triangle_edge_width()),
+            triangle_fill_color: Some(self.triangle_fill_color()),
+        }
+    }
+
+    /// Get the [`SquareStyle`] from theme and state.
+    pub fn square_style(&self) -> SquareStyle {
+        SquareStyle { square_edge_width: Some(self.square_edge_width()), square_fill_color: Some(self.square_fill_color()) }
+    }
+
+    /// Get the [`RectangleStyle`] from theme and state.
+    pub fn rectangle_style(&self) -> RectangleStyle {
+        RectangleStyle { square_edge_width: Some(self.square_edge_width()), square_fill_color: Some(self.square_fill_color()) }
+    }
+
     /// Get the [`PointSize`] from theme and state.
     pub fn point_size(&self) -> PointSize {
         self.once.point_size.or(self.local.point_size).or(self.theme.point_size).unwrap_or_default()
@@ -109,4 +148,24 @@ impl StyleResolver {
     pub fn line_color(&self) -> LineColor {
         self.once.line_color.or(self.local.line_color).or(self.theme.line_color).unwrap_or_default()
     }
+
+    /// Get the [`TriangleEdgeWidth`] from theme and state.
+    pub fn triangle_edge_width(&self) -> TriangleEdgeWidth {
+        self.once.triangle_edge_width.or(self.local.triangle_edge_width).or(self.theme.triangle_edge_width).unwrap_or_default()
+    }
+
+    /// Get the [`TriangleFillColor`] from theme and state.
+    pub fn triangle_fill_color(&self) -> TriangleFillColor {
+        self.once.triangle_fill_color.or(self.local.triangle_fill_color).or(self.theme.triangle_fill_color).unwrap_or_default()
+    }
+
+    /// Get the [`SquareEdgeWidth`] from theme and state.
+    pub fn square_edge_width(&self) -> SquareEdgeWidth {
+        self.once.square_edge_width.or(self.local.square_edge_width).or(self.theme.square_edge_width).unwrap_or_default()
+    }
+
+    /// Get the [`SquareFillColor`] from theme and state.
+    pub fn square_fill_color(&self) -> SquareFillColor {
+        self.once.square_fill_color.or(self.local.square_fill_color).or(self.theme.square_fill_color).unwrap_or_default()
+    }
 }
