@@ -1,13 +1,14 @@
 mod content;
-
 pub use self::content::StyleContext;
 use crate::*;
+use serde::{Deserialize, Serialize};
 
-/// Resolve missing style
-#[derive(Debug, Clone, Default)]
+/// Resolve when style is not specific or missing.
+#[derive(Debug, Clone, Default, PartialEq, Serialize, Deserialize)]
 pub struct StyleResolver {
     theme: StyleContext,
     local: StyleContext,
+    once: StyleContext,
 }
 
 impl StyleResolver {
@@ -21,7 +22,7 @@ impl StyleResolver {
     }
     /// Set the style of the given element.
     pub fn with_theme_style(theme: StyleContext) -> Self {
-        Self { theme, local: Default::default() }
+        Self { theme, local: Default::default(), once: Default::default() }
     }
     /// Set the style of the given element.
     pub fn get_local_style(&self) -> &StyleContext {
